Coverage report

File | function |  | statements | missing | excluded |  | coverage
--- | --- | --- | --- | --- | --- | --- | ---
savcfg / __init__.py | (no function) |  | 2 | 0 | 0 |  | 100%
savcfg / bootstrap.py | get_savia_config_service |  | 10 | 0 | 0 |  | 100%
savcfg / bootstrap.py | get_savia_config_editor |  | 12 | 0 | 0 |  | 100%
savcfg / bootstrap.py | (no function) |  | 7 | 0 | 0 |  | 100%
savcfg / core.py | Group.__init__ |  | 5 | 0 | 0 |  | 100%
savcfg / core.py | Group._validate_key |  | 2 | 1 | 0 |  | 50%
savcfg / core.py | Group._validate_value |  | 14 | 12 | 0 |  | 14%
savcfg / core.py | Group.__setitem__ |  | 3 | 0 | 0 |  | 100%
savcfg / core.py | Group.update |  | 14 | 8 | 0 |  | 43%
savcfg / core.py | Group.setdefault |  | 3 | 3 | 0 |  | 0%
savcfg / core.py | (no function) |  | 11 | 0 | 0 |  | 100%
savcfg / edit.py | VarsEditor.write |  | 0 | 0 | 1 |  | 100%
savcfg / edit.py | VarsEditor.list_vars |  | 0 | 0 | 1 |  | 100%
savcfg / edit.py | VarsEditor.read |  | 0 | 0 | 1 |  | 100%
savcfg / edit.py | ConfigEditor.__init__ |  | 1 | 0 | 0 |  | 100%
savcfg / edit.py | ConfigEditor.list |  | 1 | 0 | 0 |  | 100%
savcfg / edit.py | ConfigEditor.get |  | 5 | 0 | 0 |  | 100%
savcfg / edit.py | ConfigEditor.set |  | 1 | 0 | 0 |  | 100%
savcfg / edit.py | (no function) |  | 9 | 0 | 7 |  | 100%
savcfg / keyvault.py | KeyVaultVars.__init__ |  | 5 | 0 | 0 |  | 100%
savcfg / keyvault.py | KeyVaultVars._normalize |  | 3 | 0 | 0 |  | 100%
savcfg / keyvault.py | KeyVaultVars._denormalize |  | 3 | 0 | 0 |  | 100%
savcfg / keyvault.py | KeyVaultVars.list_vars |  | 3 | 0 | 0 |  | 100%
savcfg / keyvault.py | KeyVaultVars.read |  | 8 | 1 | 0 |  | 88%
savcfg / keyvault.py | KeyVaultVars.write |  | 1 | 0 | 0 |  | 100%
savcfg / keyvault.py | (no function) |  | 11 | 0 | 0 |  | 100%
savcfg / read.py | VarsReader.list_vars |  | 0 | 0 | 0 |  | 100%
savcfg / read.py | VarsReader.read |  | 0 | 0 | 0 |  | 100%
savcfg / read.py | VariableNotFound.__init__ |  | 2 | 0 | 0 |  | 100%
savcfg / read.py | ConfigService.__init__ |  | 3 | 0 | 0 |  | 100%
savcfg / read.py | ConfigService._list_family |  | 4 | 4 | 0 |  | 0%
savcfg / read.py | ConfigService.get_primitive |  | 11 | 0 | 0 |  | 100%
savcfg / read.py | ConfigService.get_group |  | 5 | 0 | 0 |  | 100%
savcfg / read.py | ConfigService._load_group |  | 7 | 1 | 0 |  | 86%
savcfg / read.py | (no function) |  | 16 | 0 | 0 |  | 100%
Total |  |  | 182 | 30 | 10 |  | 84%

No items found using the specified filter.